package org.mathcs.ibookmark;

/**
 * Defines how a bookmark is rendered in a list, i.e. how it is represented visually.
 * Serves as template to all items in a list of bookmarks.
 * 
 * @author Bert Wachsmuth
 * @version 1.0 (10/2013)
 */
import android.content.Context;
import android.content.SharedPreferences;
import android.graphics.Color;
import android.preference.PreferenceManager;
import android.util.TypedValue;
import android.widget.LinearLayout;
import android.widget.TextView;

public class BookmarkView extends LinearLayout
{
	private TextView url;
	private TextView title;
	
	private static SharedPreferences prefs;

	private static float TEXT_SIZE_TITLE = 24f;
	private static float TEXT_SIZE_URL = 16f;
	
	public BookmarkView(Context context)
	{
		super(context);
		
		this.url = new TextView(context);
		this.title = new TextView(context);
		this.prefs = PreferenceManager.getDefaultSharedPreferences(context);

		setOrientation(LinearLayout.VERTICAL);
		
		addView(title);
		addView(url);		
	}

	public void setData(Bookmark item)
	{
		int titleSize = 14;
		int urlSize = 12;
		try
		{
			titleSize = Integer.parseInt(prefs.getString("textSizeTitleKey", "14"));
			urlSize = Integer.parseInt(prefs.getString("textSizeUrlKey", "12"));
		}
		catch(NumberFormatException nfe)
		{
			titleSize = 14;
			urlSize = 12;
		}
		title.setText(item.getTitle());
		title.setTextSize(TypedValue.COMPLEX_UNIT_SP, titleSize);
		
		url.setText(item.getUrl());
		url.setTextSize(TypedValue.COMPLEX_UNIT_SP, urlSize);
		
		if (item.isSelected())
		{
			title.setBackgroundColor(Color.GRAY);
			url.setBackgroundColor(Color.GRAY);
		}
		else
		{
			title.setBackgroundColor(Color.WHITE);
			url.setBackgroundColor(Color.WHITE);
		}
	}
}
